@@ -20,6 +20,7 @@ package opennlp.tools.formats.muc;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.Reader;
+import java.nio.charset.StandardCharsets;
 
 import org.junit.Test;
 
@@ -29,7 +30,7 @@ public class SgmlParserTest {
   public void testParse1() throws IOException {
 
     try (Reader in = new InputStreamReader(
-        SgmlParserTest.class.getResourceAsStream("parsertest1.sgml"), "UTF-8")) {
+        SgmlParserTest.class.getResourceAsStream("parsertest1.sgml"), StandardCharsets.UTF_8)) {
       SgmlParser parser = new SgmlParser();
       parser.parse(in, new SgmlParser.ContentHandler() {
       });
